ynf

产品支持情况

  • Ascend 950PR&950DT系列产品:支持
  • Atlas A3系列产品:不支持
  • Atlas A2系列产品:不支持
  • Atlas 200I/500 A2推理产品:不支持
  • Atlas推理系列产品AI Core:不支持
  • Atlas推理系列产品Vector Core:不支持
  • Atlas训练系列产品:不支持

功能说明

头文件路径为:"simt_api/math_functions.h"。

获取输入数据x的n阶第二类贝塞尔函数yn的值。

函数原型

inline float ynf(int n, float x)

参数说明

表1 参数说明

参数名 输入/输出 描述
n 输入 源操作数。
x 输入 源操作数。

返回值说明

输入数据的第二类贝塞尔函数yn的值。

  • 当n<0时,返回值为nan。
  • 当x=0时,返回值为-inf。
  • 当x<0时,返回值为nan。
  • 当x=inf时,返回值为0。
  • 当x=nan时,返回值为nan。
  • 在快速计算模式(--cce-use-fast-math设置为true)下,若内部计算的除数为Subnormal数据,则接口返回值为±inf。

约束说明

  • n的最大取值为128。
  • 本接口受编译选项--cce-use-fast-math的影响。
    • --cce-use-fast-math=true:开启快速计算模式。本接口内部实现使用到了除法运算符,由于快速计算模式下除法运算符不支持Subnormal场景,因此本接口不支持内部计算的除数为Subnormal数据的场景。
    • --cce-use-fast-math=false:支持Subnormal场景的高精度计算。

调用示例

  • SIMT编程场景:

    #include "simt_api/math_functions.h"
    
    __global__ __launch_bounds__(256) void compute_ynf(float *result, const int *n, const float *x, uint32_t count)
    {
        const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x;
        if (idx >= count) {
            return;
        }
        result[idx] = ynf(n[idx], x[idx]);
    }
    
  • SIMD与SIMT混合编程场景:

    #include "simt_api/math_functions.h"
    
    __simt_vf__ __launch_bounds__(256) inline void compute_ynf_vf(__gm__ float *result, __gm__ const int *n, __gm__ const float *x, uint32_t count)
    {
        const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x;
        if (idx >= count) {
            return;
        }
        result[idx] = ynf(n[idx], x[idx]);
    }
    
    __global__ __vector__ void run_ynf(__gm__ float *result, __gm__ const int *n, __gm__ const float *x, uint32_t count)
    {
        asc_vf_call<compute_ynf_vf>(dim3(256), result, n, x, count);
    }
    

输入输出示例如下:

n:1, 2, 3, 1
x:1, 2, 3, 4
result: -0.7812128 -0.6174081 -0.5385417 0.3979257